@@ -15,6 +15,11 @@ def batch_api_calls(url, params, input_list, batch_size):
     for i in range(0, len(input_list), batch_size):
         headers = {'Authorization': f'Bearer {_auth.get_access_token()}'}
         response = _requests.post(url, params=params, headers=headers, json=input_list[i:i + batch_size])
+        
+        # Checking status code
+        if str(response.status_code)[0] != '2':
+            raise ValueError(f"Status Code: {response.status_code} - {response.reason}. \n")
+        
         results = results + response.json()
 
     return results
\ No newline at end of file
