@@ -3,9 +3,13 @@ Connectors to read/write from external systems
 """
 
 from . import file
+from . import http
 from . import mssql
+from . import mysql
+from . import notification
 from . import postgres
 from . import pricefx
-from . import table
+from . import test
 from . import ssh
-from . import notification
\ No newline at end of file
+from . import sftp
+from . import mongodb
\ No newline at end of file
