@@ -1,15 +1,15 @@
-import apprise
+import apprise as _apprise
 
 
 _schema = {}
 
 
-def execute(url: str, title: str, body: str):
-    app_object = apprise.Apprise()
+def run(url: str, title: str, body: str):
+    app_object = _apprise.Apprise()
     app_object.add(url)
     app_object.notify(body, title)
 
-_schema['execute'] = """
+_schema['run'] = """
 type: object
 description: Send a notification
 required:
