@@ -1,18 +1,18 @@
 """
 Connector for SSH
 """
-from fabric import Connection
+from fabric import Connection as _Connection
 
 
 _schema = {}
 
-def execute(host: str, user: str, password: str, command: str) -> None:
+def run(host: str, user: str, password: str, command: str) -> None:
     """
     Execute a command over ssh
     """
-    Connection(host, user=user, connect_kwargs={'password': password}).run(command)
+    _Connection(host, user=user, connect_kwargs={'password': password}).run(command)
 
-_schema['execute'] = """
+_schema['run'] = """
 type: object
 description: Issue commands over SSH
 required:
