@@ -100,12 +100,27 @@ def custom(input: _Union[str, list], model_id: str) -> list:
         json_data = input
     else:
         raise TypeError('Invalid input data provided. The input must be either a string or a list of strings.')
+        
+    # If the Model Id is not appropriate, raise error (Maybe more specific?)
+    if isinstance(model_id, dict) or len(model_id.split('-')) != 3:
+        raise ValueError('Incorrect model_id. May be missing "${ }" around value')
+        
+    # Checking to see if GUID format is correct
+    if [len(x) for x in model_id.split('-')] != [8, 4, 4]:
+        raise ValueError('Incorrect or missing values in model_id. Check format is XXXXXXXX-XXXX-XXXX')
 
     url = f'{_config.api_host}/wrangles/extract/custom'
     params = {'responseFormat': 'array', 'model_id': model_id}
     model_properties = _data.model(model_id)
+    # If model_id format is correct but no mode_id exists
+    if model_properties.get('message', None) == 'error': raise ValueError('Incorrect model_id.\nmodel_id may be wrong or does not exists')
     batch_size = model_properties['batch_size'] or 10000
-
+    
+    # Using model_id in wrong function
+    purpose = model_properties['purpose']
+    if purpose != 'extract':
+        raise ValueError(f'Using {purpose} model_id in an extract function.')
+    
     results = _batching.batch_api_calls(url, params, json_data, batch_size)
 
     if isinstance(input, str): results = results[0]
@@ -139,6 +154,30 @@ def geography(input: _Union[str, list], dataType: str) -> list:
     return results
 
 
+def html(input: _Union[str, list], dataType: str) -> list:
+    """
+    Extract specific html elements from strings containing html.
+
+    :param input: A string or list of strings with addresses to search for information.
+    :param dataType: The type of information to return. 'text' or 'links'
+    :return: A list of any results found.
+    """
+    if isinstance(input, str): 
+        json_data = [input]
+    else:
+        json_data = input
+
+    url = f'{_config.api_host}/wrangles/extract/html'
+    params = {'responseFormat': 'array', 'dataType': dataType}
+    batch_size = 10000
+
+    results = _batching.batch_api_calls(url, params, json_data, batch_size)
+
+    if isinstance(input, str): results = results[0]
+    
+    return results
+
+    
 def properties(input: _Union[str, list], type: str = None) -> _Union[dict, list]:
     """
     Extract categorical properties from unstructured text such as colours or materials.
@@ -169,20 +208,38 @@ def properties(input: _Union[str, list], type: str = None) -> _Union[dict, list]
 
 
 # SUPER MARIO
-from boltons.setutils import IndexedSet
-def diff(input):
+def remove_words(input, to_remove):
     """
-    input is going to be list of lists, where each list contains tokens
-    diff subtracts the tokens in 2nd list from the first using set ops
-    All inputs are "lowered" before difference operation
-    """
-    results = []
-    for row in input:
-        # target = row[0].lower()
-        target = [x.lower() for x in row[0]]
-        # remove = row[1].lower()
-        remove = [x.lower() for x in row[1]]
-        result = list(IndexedSet(target).difference(remove))
-        results.append([x.lower() for x in result])
+    Remove all the elements that occur in one list from another.
     
-    return results
\ No newline at end of file
+    :param input: both input and to_remove can be a string or a list or multiple lists. Lowered for precision
+    :param output: a string of remaining words
+    """
+        
+    # Input is string
+    if isinstance(input[0], str):
+        input_lower = [x.lower() for x in input]
+        input = [[x.split()] for x in input_lower]
+        results = []
+        for item in range(len(input)):
+            temp = []
+            to_remove_lower = [item.lower() for sublist in to_remove[item] for item in sublist]
+            temp = filter(None, [x.title() for x in input[item][0] if x not in to_remove_lower])
+            results.append(' '.join(temp))
+        
+        return results
+        
+    
+    # Input is list
+    results = []
+    for item in range(len(input)):
+        temp = []
+        to_remove_lower = [item.lower() for sublist in to_remove[item] for item in sublist]
+        input_lower = [x.lower() for x  in input[item]]
+        temp = filter(None, [x.title() for x in input_lower if x not in to_remove_lower])
+        results.append(' '.join(temp))
+
+        
+    return results
+    
+    
\ No newline at end of file
